@@ -1,5 +1,4 @@
 from matplotlib.image import NonUniformImage
-from sklearn.metrics import auc
 from collections.abc import Iterable
 import matplotlib as mpl
 from smpl import plot as splot
@@ -16,6 +15,7 @@ from matplotlib import colors
 from .input import Input, get_output_dir, replace_macros
 from .util import get_name
 from matplotlib.ticker import NullFormatter
+from scipy import integrate as auc
 
 
 def title(i: Input,
@@ -161,7 +161,7 @@ def plot(dict_list,
     if K:
         yaxis = "$K$"
         yscale = 1.0
-        vy = vy / splot.unv(dict_list["LO"][mask])
+        vy = vy / splot.unv(dict_list["LO"].to_numpy()[mask])
         if K_plus_1:
             vy = vy + vy / vy
     if ratio:
@@ -253,7 +253,7 @@ def vplot(x,
         ix = iii[1]
         iy = iii[2]
     if print_area:
-        print('computed AUC using sklearn.metrics.auc: {}'.format(auc(ix, iy)))
+        print('computed AUC using scipy.integrate.simpson: {}'.format(auc.simpson(iy, ix)))
     if ((np.any(np.less(vy, 0)) or (interpolate and np.any(np.less(iy, 0))))
             and logy):
         splot.data(vx,
@@ -319,14 +319,14 @@ def mapplot(dict_list, x, y, z, xaxis=None, yaxis=None, zaxis=None, **kwargs):
     splot.plot2d(vx,
                  vy,
                  vz,
-                 style="image",
+                 style="pcolormesh",
                  xaxis=xaxis,
                  yaxis=yaxis,
                  zaxis=zaxis,
                  **kwargs)
 
 
-map_vplot = lambda *a, **da: splot.plot2d(*a, style="image", **da)
+map_vplot = lambda *a, **da: splot.plot2d(*a, style="pcolormesh", **da)
 scatter_vplot = lambda *a, **da: splot.plot2d(*a, style="scatter", **da)
 
 
@@ -384,14 +384,14 @@ def err_plt(axes, x, y, label=None, error=False):
     v = label
     ind = np.argsort(splot.unv(x), kind='stable')
     if error:
-        l, _, _ = axes.errorbar(x[ind],
+        l, _, _ = axes.errorbar(x.to_numpy()[ind],
                                 splot.unv(y)[ind],
                                 yerr=splot.usd(y),
                                 capsize=5,
                                 label=v)
         return l
     else:
-        l = axes.plot(x[ind], splot.unv(y)[ind], label=v)
+        l = axes.plot(x.to_numpy()[ind], splot.unv(y)[ind], label=v)
         return l[0]
 
 
