@@ -3,7 +3,6 @@ from .util import DictData
 import numpy as np
 from uncertainties import unumpy
 from smpl import plot
-import lhapdf
 import warnings
 import tqdm
 #from pqdm.processes import pqdm as ppqdm
@@ -94,7 +93,7 @@ class Result(DictData):
 def pdf_errors(li,
                dl,
                ordernames=None,
-               confidence_level=90):
+               confidence_level=90,n_jobs=None):
     """
     Just like `pdf_error` but over a list of ordernames.
     """
@@ -102,12 +101,13 @@ def pdf_errors(li,
         ordernames = ["LO", "NLO", "aNNLO_PLUS_NNLL"]
     r_dl = dl
     for o in ordernames:
-        r_dl = pdf_error(li, r_dl, o, confidence_level=confidence_level)
+        r_dl = pdf_error(li, r_dl, o, confidence_level=confidence_level,n_jobs=n_jobs)
 
     return r_dl
 
 
-def pdf_error_single(members, i, dl, ordername, confidence_level=90):
+def _pdf_error_single(members, i, dl, ordername, confidence_level=90):  
+    #import lhapdf
     if dl["pdfset_nlo"][i] == 0 and dl["mu_f"][i] == 1.0 and dl["mu_r"][
             i] == 1.0:
         pdfset = lhapdf.getPDFSet(dl["pdf_nlo"][i])
@@ -134,7 +134,7 @@ def pdf_error_single(members, i, dl, ordername, confidence_level=90):
     return (i,nlo_unc)
 
 
-def pdf_error(li, dl, ordername="LO", confidence_level=90):
+def pdf_error(li, dl, ordername="LO", confidence_level=90, n_jobs=None):
     """
     Computes Parton Density Function (PDF) uncertainties through :func:`lhapdf.set.uncertainty`.
 
@@ -145,10 +145,16 @@ def pdf_error(li, dl, ordername="LO", confidence_level=90):
         confidence_level (:obj:`double`): Confidence Level for PDF uncertainty
 
     Returns:
-        :obj:`dict`: Modified `dl` with new `LO`/`NLO`/`NLO_PLUS_NLL` _ `PDF`/`PDF_CENTRAL`/`PDF_ERRPLUS`/`PDF_ERRMINUS`/`PDF_ERRSYM` entries.
-            - `LO`/`NLO`/`NLO_PLUS_NLL` _ `PDF` contains a symmetrized :mod:`uncertainties` object.
+        :obj:`dict`: Modified `dl` with new `ordername_{PDF,PDF_CENTRAL,PDF_ERRPLUS,PDF_ERRMINUS,PDF_ERRSYM}` entries.
+            - (`ordername`)_`PDF` contains a symmetrized :mod:`uncertainties` object.
     """
     global required_numerical_uncertainty_factor
+    try:
+        import lhapdf
+    except ImportError:
+        raise RuntimeError("LHAPDF with python bindings needed to compute PDF uncertainties. Make sure you set the PYTHONPATH correctly (i.e. correct python version).")
+    if not lhapdf.availablePDFSets():
+        raise RuntimeError("No PDF sets found. Make sure the environment variable LHAPDF_DATA_DIR points to the correct location (.../share/LHAPDF).")
     example = li[0]
     members = [
         attr for attr in dir(example)
@@ -170,8 +176,8 @@ def pdf_error(li, dl, ordername="LO", confidence_level=90):
     } for i in range(len(dl["pdfset_nlo"])) if dl["pdfset_nlo"][i] == 0
             and dl["mu_f"][i] == 1.0 and dl["mu_r"][i] == 1.0]
     ret = tpqdm(args,
-                pdf_error_single,
-                n_jobs=mp.cpu_count(),
+                _pdf_error_single,
+                n_jobs=n_jobs if n_jobs is not None else mp.cpu_count(),
                 argument_type='kwargs',
                 desc="PDF uncertainty @ " + ordername)
     for i, nlo_unc in ret:
@@ -206,7 +212,7 @@ def pdf_error(li, dl, ordername="LO", confidence_level=90):
     return dl
 
 
-def scale_errors(li, dl, ordernames=None):
+def scale_errors(li, dl, ordernames=None,n_jobs=None):
     """
     Just like `scale_error` but over a list of ordernames.
     """
@@ -214,11 +220,11 @@ def scale_errors(li, dl, ordernames=None):
         ordernames = ["LO", "NLO", "aNNLO_PLUS_NNLL"]
     r_dl = dl
     for o in ordernames:
-        r_dl = scale_error(li, r_dl, o)
+        r_dl = scale_error(li, r_dl, o, n_jobs=n_jobs)
 
     return r_dl
 
-def scale_error_single(members,i,dl,ordername="LO"):
+def _scale_error_single(members,i,dl,ordername="LO"):
     if dl["pdfset_nlo"][i] == 0 and dl["mu_f"][i] == 1.0 and dl["mu_r"][
         i] == 1.0:
         scales = []
@@ -234,7 +240,7 @@ def scale_error_single(members,i,dl,ordername="LO"):
         np.min( [plot.unv(dl[ordername][k]) for k in scales]) - plot.unv(dl[ordername][i])
     )
 
-def scale_error(li, dl, ordername="LO"):
+def scale_error(li, dl, ordername="LO",n_jobs=None):
     """
     Computes seven-point scale uncertainties from the results where the renormalization and factorization scales are varied by factors of 2 and  relative factors of four are excluded (cf. :meth:`seven_point_scan`).
 
@@ -243,8 +249,8 @@ def scale_error(li, dl, ordername="LO"):
         dl (:obj:`dict`): :class:`Result` dictionary with lists per entry.
 
     Returns:
-        :obj:`dict`: Modified `dl` with new `LO`/`NLO`/`NLO_PLUS_NLL` _ `SCALE`/`SCALE_ERRPLUS`/`SCALE_ERRMINUS`/`SCALE_ERRSYM` entries.
-            - `LO`/`NLO`/`NLO_PLUS_NLL` _ `SCALE` contains a symmetrized :mod:`uncertainties` object.
+        :obj:`dict`: Modified `dl` with new `ordername_{SCALE,SCALE_ERRPLUS,SCALE_ERRMINUS}` entries.
+            - `ordername_SCALE` contains a symmetrized :mod:`uncertainties` object.
     """
     global required_numerical_uncertainty_factor
     example = li[0]
@@ -266,8 +272,8 @@ def scale_error(li, dl, ordername="LO"):
     } for i in range(len(dl["pdfset_nlo"])) if dl["pdfset_nlo"][i] == 0
             and dl["mu_f"][i] == 1.0 and dl["mu_r"][i] == 1.0]
     ret = tpqdm(args,
-                scale_error_single,
-                n_jobs=mp.cpu_count(),
+                _scale_error_single,
+                n_jobs=n_jobs if n_jobs is not None else mp.cpu_count(),
                 argument_type='kwargs',
                 desc="Scale uncertainty @ " + ordername)
     for i,errplus,errminus in ret:
@@ -326,8 +332,8 @@ def combine_error(dl: dict, ordername="LO"):
         dl (:obj:`dict`): :class:`Result` dictionary with lists per entry.
 
     Returns:
-        :obj:`dict`: Modified `dl` with new `LO`/`NLO`/`NLO_PLUS_NLL` _ `COMBINED`/`ERRPLUS`/`ERRMINUS` entries.
-            - `LO`/`NLO`/`NLO_PLUS_NLL` _ `COMBINED` contains a symmetrized :mod:`uncertainties` object.
+        :obj:`dict`: Modified `dl` with new `ordername_{COMBINED,ERRPLUS,ERRMINUS}` entries.
+            - `ordername_COMBINED` contains a symmetrized :mod:`uncertainties` object.
     """
     dl[ordername + "_NOERR"] = np.array([None] * len(dl["pdfset_nlo"]))
     dl[ordername + "_ERRPLUS"] = np.array([None] * len(dl["pdfset_nlo"]))
